static_map_service library

A type-safe Dart package for generating static map image URLs.

Currently supports:

  • Google Maps Static API
  • Apple Maps Web Snapshots
  • Mapbox Static Images API

Example:

import 'package:static_map_service/static_map_service.dart';

final url = GoogleMapService.center(
  key: 'YOUR_API_KEY',
  center: MapLatLng(latitude: 35.6812, longitude: 139.7671),
  zoom: 12,
  size: GoogleMapSize(width: 400, height: 400),
).url;

Classes

AppleMapService
Apple Maps Web Snapshots API service.
GoogleMapService
Google Maps Static API service.
MapboxMapService
Mapbox Static Images API service.
MapService
The base class for all map services.

Enums

AppleMapAnnotationStyle
The style of the annotation.
AppleMapColorScheme
The color scheme of the map.
AppleMapType
The type of map to display.
GoogleMapElementGeometry
Geometry element types.
GoogleMapElementLabels
Label element types.
GoogleMapFeatureAdministrative
Administrative feature types.
GoogleMapFeatureLandscape
Landscape feature types.
GoogleMapFeaturePoi
Point of interest feature types.
GoogleMapFeatureRoad
Road feature types.
GoogleMapFeatureTransit
Transit feature types.
GoogleMapFormat
The format of the resulting image.
GoogleMapMarkerSize
Marker size presets.
GoogleMapStyleRuleVisibility
Visibility rule types.
GoogleMapType
The type of map to display.
MapboxMarkerSize
Marker size presets for Mapbox.

Extension Types

AppleMapAnnotation
An annotation to display on the map.
AppleMapAnnotationColor
A color representation for Apple Map annotations.
AppleMapAnnotationOffset
An offset in scale independent pixels from the bottom center.
AppleMapImage
An image to display on the map.
AppleMapOverlay
An overlay (polyline or polygon) to display on the map.
AppleMapSize
The size of the map image in pixels.
GoogleMapColor
Color presets and hex colors for Google Map markers and paths.
GoogleMapElement
Map elements to style.
GoogleMapFeature
Features to style on the map.
GoogleMapMarkers
A set of markers to display on the map.
GoogleMapPath
A path (polyline or polygon) to display on the map.
GoogleMapSize
The size of the map image in pixels.
GoogleMapStyle
Custom styling rule for a map element.
GoogleMapStyleRule
Styling rules to apply.
GoogleMapViewports
A set of locations to be visible on the map.
MapAddress
A representation of a location defined by a physical address or place name.
MapboxGeoJson
A GeoJSON overlay for Mapbox.
MapboxMapOverlay
Base class for all Mapbox overlays.
MapboxMapSize
The size of the Mapbox map image in pixels.
MapboxMarker
A marker overlay for Mapbox.
MapboxPath
A path (polyline) overlay for Mapbox.
MapLatLng
A representation of geographic coordinates (latitude and longitude).
MapLocation
The base class for map location representation.

Constants

centerLocation → const MapAddress
Helper constant for the 'center' location.

Typedefs

SignatureFunction = String Function(String pathAndParams)
A function type used to generate a digital signature for a given URL path and parameters.